@@ -28,7 +28,7 @@ default = {}
 
 
 def read_config():
-    f = os.path.expanduser('~/.bugrc')
+    f = os.path.expanduser('~/.bugzillarc')
     if not os.path.isfile(f):
         # file doesn't exist; empty config
         return None
@@ -41,13 +41,7 @@ config = read_config()
 def get(key):
     if not config:
         return None
-    try:
-        return config[key]
-    except KeyError:
-        try:
-            return default[key]
-        except KeyError:
-            return None
+    return config.get(key) or default.get(key)
 
 
 def get_show_fields():
